FRouterDelegate class
- Inheritance
-
- Object
- Listenable
- RouterDelegate<
FRouteMatch> - BaseRouterDelegate<
FRouteMatch> - FRouterDelegate
- Mixed-in types
-
- PopNavigatorRouterDelegateMixin<
FRouteMatch> - ChangeNotifier
- LoggingMixin
- ThrottledChangeNotifier
- PopNavigatorRouterDelegateMixin<
Constructors
-
FRouterDelegate(FRouteState state, FRouter routes, {required String path, required FRouterDelegate parent, required AppRoute<
dynamic, RouteParams> ? initialRoute, List<HistoryObserver> historyObservers = const [], required bool preferUpdates}) -
FRouterDelegate.root(FRouteState state, FRouter routes, {List<
HistoryObserver> historyObservers = const [], required AppRoute<dynamic, RouteParams> ? initialRoute, required String path, required bool preferUpdates, })
Properties
- currentConfiguration → FRouteMatch?
-
Called by the Router when it detects a route information may have
changed as a result of rebuild.
no setteroverride
- currentRoute → PendingRoute?
-
no setter
- debugLabel ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasParent → bool
-
no setter
-
historyObservers
→ List<
HistoryObserver> -
final
-
initialRoute
→ AppRoute<
dynamic, RouteParams> ? -
The starting route for this delegate
final
- isActive → bool
-
no setterinherited
- isRoot → bool
-
no setter
- limiter → Limiter
-
final
- log → Logger
-
no setterinherited
- loggerName → String
-
no setterinherited
-
The key used for retrieving the current navigator.
final
- parent → FRouterDelegate?
-
final
- path → String
-
final
- preferUpdates → bool
-
final
- rootDelegate → FRouterDelegate
-
no setter
- rootState → FRouteState
-
no setter
- routes → FRouter
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → FRouteState
-
final
Methods
-
activateChild(
FRouterDelegate child) → void -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
build(
BuildContext context) → Widget -
Called by the Router to obtain the widget tree that represents the
current state.
override
-
calculateInitialRoute(
) → String -
dispose(
) → void -
Discards any resources used by the object.
override
-
fromRouteInformation(
RouteInformation info) → AppRouteMatch< dynamic, RouteParams> ? -
ifActive<
R> (R exec()) → R? -
inherited
-
init(
) → void -
makeActive(
) → void -
matchAppRoute(
AppRoute< dynamic, RouteParams> appRoute, RouteParams params) → FRouteMatch -
matchPage(
String route) → FRouteMatch -
matchRoute(
RouteInformation routeInformation) → FRouteMatch -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyIfActive(
) → void -
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
notifyWithLimit(
) → void -
inherited
-
popRoute(
) → Future< bool> -
Called by the Router when the Router.backButtonDispatcher reports that
the operating system is requesting that the current route be popped.
override
-
push(
AppRoute< dynamic, RouteParams> route, {RouteParams? args}) → void -
pushNamed(
String route) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reportPop(
FRouteInformation information) → dynamic -
reportPush(
FRouteInformation information) → dynamic -
setInitialRoutePath(
FRouteMatch configuration) → Future< void> -
Called by the Router at startup with the structure that the
RouteInformationParser obtained from parsing the initial route.
override
-
setNewRoutePath(
FRouteMatch configuration) → Future< void> -
Called by the Router when the Router.routeInformationProvider reports that a
new route has been pushed to the application by the operating system.
override
-
setRestoredRoutePath(
FRouteMatch configuration) → Future< void> -
Called by the Router during state restoration.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
tryMatchAppRoute(
AppRoute< dynamic, RouteParams> route, RouteParams params, [Set? checked]) → FRouteMatch? -
tryMatchRoute(
RouteInformation routeInformation, [Set? checked]) → FRouteMatch?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited